@@ -38,21 +38,22 @@ namespace Help
 		cout<<"\n";
 		cout<<" -B, --batch-recursive=<wc>     convert all matching files, searches subdirs\n";
 		cout<<"                                  (Example: -B '*.cpp')\n";
-		cout<<" -D, --data-dir=<directory>     set path to data directory\n";
-		cout<<"     --add-config-dir=<dir>     set path to an additional config directory\n";
+		cout<<" -D, --data-dir=<directory>     set path to data directory (deprecated)\n";
 		cout<<"     --config-file=<file>       set path to a lang or theme file\n";
 		cout<<" -d, --outdir=<directory>       name of output directory\n";
 		cout<<" -h, --help                     print this help\n";
 		cout<<" -i, --input=<file>             name of single input file\n";
 		cout<<" -o, --output=<file>            name of single output file\n";
 
-		cout<<" -p, --list-langs               list installed language definitions\n";
+		cout<<" -p, --list-langs               list installed language definitions (deprecated)\n";
 		cout<<" -P, --progress                 print progress bar in batch mode\n";
 		cout<<" -q, --quiet                    supress progress info in batch mode\n";
 		cout<<" -S, --syntax=<type>            specify type of source code\n";
 		cout<<" -v, --verbose                  print debug info\n";
-		cout<<" -w, --list-themes              list installed colour themes\n";
+		cout<<" -w, --list-themes              list installed colour themes (deprecated)\n";
 		cout<<"     --force                    generate output if input syntax is unknown\n";
+		cout<<"     --list-scripts=<type>      list installed scripts\n";
+		cout<<"                                  <type>=[langs, themes, plugins]\n";
 		cout<<"     --plug-in=<script>         execute Lua plug-in script; repeat option to\n";
 		cout<<"                                  execute multiple plug-ins\n";
 		cout<<"     --plug-in-read=<path>      set input file for a plug-in (e.g. \"tags\")\n";
@@ -70,7 +71,7 @@ namespace Help
 		cout<<"\n";
 		cout<<" -O, --out-format=<format>      output file in given format\n";
 		cout<<"                                  <format>=[html, xhtml, latex, tex,\n";
-		cout<<"                                  rtf, ansi, xterm256, bbcode, svg]\n";
+		cout<<"                                  odt, rtf, ansi, xterm256, bbcode, svg]\n";
 		cout<<" -c, --style-outfile=<file>     name of style file or print to stdout, if\n";
 		cout<<"                                  'stdout' is given as file argument\n";
 
@@ -92,16 +93,18 @@ namespace Help
 		cout<<" -t, --replace-tabs=<num>       replace tabs by <num> spaces\n";
 		cout<<" -T, --doc-title=<title>        document title\n";
 		cout<<" -u, --encoding=<enc>           set output encoding which matches input file\n";
-		cout<<"                                  encoding; omit encoding info if enc=NONE\n";
+		cout<<"                                  encoding; omit encoding info if set to NONE\n";
 		cout<<" -V, --wrap-simple              wrap long lines without indenting function\n";
 		cout<<"                                  parameters and statements\n";
 		cout<<" -W, --wrap                     wrap long lines\n";
+		cout<<"     --wrap-no-numbers          omit line numbers of wrapped lines\n";
+		cout<<"                                  (assumes -l)\n";
 		cout<<" -z, --zeroes                   pad line numbers with 0's\n";
 		cout<<"     --kw-case=<case>           change case of case insensitive keywords\n";
 		cout<<"                                  <case> =  [upper, lower, capitalize]\n";
 		cout<<"     --delim-cr                 set CR as end-of-line delimiter (MacOS 9)\n";
 		cout<<"     --no-trailing-nl           omit trailing newline\n";
-		cout<<"\n";
+		cout<<"\n\n";
 		cout<<"(X)HTML output options:\n";
 		cout<<"\n";
 		cout<<" -a, --anchors                  attach anchor to line numbers\n";
@@ -109,14 +112,12 @@ namespace Help
 		cout<<" -N, --anchor-filename          use input file name as anchor prefix\n";
 		cout<<" -C, --print-index              print index with hyperlinks to output files\n";
 		cout<<" -n, --ordered-list             print lines as ordered list items\n";
-		cout<<"     --class-name=<str>         set CSS class name prefix\n";
+		cout<<"     --class-name=<name>        set CSS class name prefix;\n";
+		cout<<"                                  omit class name if set to NONE\n";
 		cout<<"     --inline-css               output CSS within each tag (verbose output)\n";
 		cout<<"     --enclose-pre              enclose fragmented output with pre tag \n";
 		cout<<"                                  (assumes -f)\n";
-		cout<<"     --ctags-file[=<file>]      read ctags file to include meta information as\n";
-		cout<<"                                  tooltips (default value: tags)\n";
-		cout<<"                                  DEPRECATED: use ctags plug-in instead\n";
-		cout<<"\n";
+		cout<<"\n\n";
 		cout<<"LaTeX output options:\n";
 		cout<<"\n";
 		cout<<" -b, --babel                    disable Babel package shorthands\n";
@@ -160,6 +161,7 @@ namespace Help
 		cout<<"Reformatting code (-F) will only work with C, C++, C# and Java input files.\n";
 		cout<<"Wrapping lines with -V or -W will cause faulty highlighting of long single\n";
 		cout<<"line comments and directives. Use with caution.\n";
+		cout<<"See README how to install own scripts in the home directory.\n";
 		cout<<"\n";
 		cout<<"Updates and information: http://www.andre-simon.de/\n";
 	}
