@@ -2,7 +2,7 @@
                           main.cpp  -  description
                              -------------------
     begin                : Die Apr 23 22:16:35 CEST 2002
-    copyright            : (C) 2002-2009 by Andre Simon
+    copyright            : (C) 2002-2012 by Andre Simon
     email                : andre.simon1@gmx.de
 
    Highlight is a universal source code to HTML converter. Syntax highlighting
@@ -34,9 +34,8 @@ along with Highlight.  If not, see <http://www.gnu.org/licenses/>.
 #include <algorithm>
 #include <Diluculum/LuaState.hpp>
 
-
 #include "main.h"
-#include "re/Pattern.h"
+#include "../include/datadir.h"
 #include "syntaxreader.h"
 
 #define MAX_LINE__WIDTH       80
@@ -47,16 +46,14 @@ void HLCmdLineApp::printVersionInfo()
 {
     cout << "\n highlight version "
          << HIGHLIGHT_VERSION
-         << "\n Copyright (C) 2002-2012 Andre Simon <andre.simon1 at gmx.de>"
+         << "\n Copyright (C) 2002-2013 Andre Simon <andre.simon1 at gmx.de>"
          << "\n\n Argparser class"
          << "\n Copyright (C) 2006-2008 Antonio Diaz Diaz <ant_diaz at teleline.es>"
          << "\n\n Artistic Style Classes (2.02.1)"
          << "\n Copyright (C) 2006-2011 by Jim Pattee <jimp03 at email.com>"
          << "\n Copyright (C) 1998-2002 by Tal Davidson"
-         << "\n\n Diluculum Lua wrapper (0.5.3)"
-         << "\n Copyright (C) 2005-2010 by Leandro Motta Barros"
-         << "\n\n Regex library (1.09.00)"
-         << "\n Copyright (C) 2003-2008 Jeffery Stuart <stuart at cs.unr.edu>"
+         << "\n\n Diluculum Lua wrapper (1.0)"
+         << "\n Copyright (C) 2005-2013 by Leandro Motta Barros"
          << "\n\n xterm 256 color matching functions"
          << "\n Copyright (C) 2006 Wolfgang Frisch <wf at frexx.de>"
 
@@ -75,12 +72,10 @@ void HLCmdLineApp::printBadInstallationInfo()
          << OPT_DATADIR << ".\n";
 }
 
-bool HLCmdLineApp::printInstalledThemes()
+int HLCmdLineApp::printInstalledFiles(const string& where, const string& wildcard, const string& what, const string&option)
 {
     vector <string> filePaths;
-    string wildcard="*.theme";
-    string directory= dataDir.getThemePath();
-    string searchDir = directory + wildcard;
+    string searchDir = where + wildcard;
 
     bool directoryOK = Platform::getDirectoryEntries ( filePaths, searchDir, true );
     if ( !directoryOK )
@@ -88,27 +83,27 @@ bool HLCmdLineApp::printInstalledThemes()
         cerr << "highlight: Could not access directory "
              <<  searchDir
              << ", aborted.\n";
-        return false;
+        return EXIT_FAILURE;
     }
 
-    cout << "\nInstalled themes"
-         << " (located in " << directory << "):\n\n";
+    cout << "\nInstalled "<< what << " (located in " << where << "):\n\n";
 
     sort ( filePaths.begin(), filePaths.end() );
     string temp;
 
-    for ( unsigned int i=0;i< filePaths.size(); i++ )
+    for ( unsigned int i=0; i< filePaths.size(); i++ )
     {
-        temp = ( filePaths[i] ).substr ( directory.length() );
+        temp = ( filePaths[i] ).substr ( where.length() );
         cout <<temp.substr ( 1, temp.length()- wildcard.length() ) << endl;
     }
-    cout <<"\nUse name of the desired theme"
-         << " with the --" OPT_STYLE " option.\n" << endl;
-    return true;
+    cout <<"\nUse name of the desired "<<what
+         << " with the --" <<option<< " option.\n" << endl;
+	 
+    return EXIT_SUCCESS;
 }
 
 
-bool HLCmdLineApp::printInstalledLanguages()
+int HLCmdLineApp::printInstalledLanguages()
 {
     vector <string> filePaths;
     string wildcard="*.lang";
@@ -121,7 +116,7 @@ bool HLCmdLineApp::printInstalledLanguages()
         cerr << "highlight: Could not access directory "
              <<  searchDir
              << ", aborted.\n";
-        return false;
+        return EXIT_FAILURE;
     }
 
     sort ( filePaths.begin(), filePaths.end() );
@@ -129,17 +124,17 @@ bool HLCmdLineApp::printInstalledLanguages()
     cout << "\nInstalled language definitions"
          << " (located in " << directory << "):\n\n";
 
-    for ( unsigned int i=0;i< filePaths.size(); i++ )
+    for ( unsigned int i=0; i< filePaths.size(); i++ )
     {
         Diluculum::LuaState ls;
-	highlight::SyntaxReader::initLuaState(ls, filePaths[i],"");
+        highlight::SyntaxReader::initLuaState(ls, filePaths[i],"");
         ls.doFile(filePaths[i]);
         desc = ls["Description"].value().asString();
         suffix = ( filePaths[i] ).substr ( directory.length() ) ;
         suffix = suffix.substr ( 1, suffix.length()- wildcard.length() );
         cout << setw ( 30 ) <<setiosflags ( ios::left ) <<desc<<": "<<suffix;
         int extCnt=0;
-        for (StringMap::iterator it=extensions.begin();it!=extensions.end();it++) {
+        for (StringMap::iterator it=extensions.begin(); it!=extensions.end(); it++) {
             if (it->second==suffix ) {
                 cout << ((++extCnt==1)?" ( ":" ")<<it->first;
             }
@@ -148,7 +143,7 @@ bool HLCmdLineApp::printInstalledLanguages()
     }
     cout <<"\nUse name of the desired language"
          << " with the --" OPT_SYNTAX " option.\n" << endl;
-    return true;
+    return EXIT_SUCCESS;
 }
 
 void HLCmdLineApp::printDebugInfo ( const highlight::SyntaxReader *lang,
@@ -159,35 +154,40 @@ void HLCmdLineApp::printDebugInfo ( const highlight::SyntaxReader *lang,
     cerr << "\n\nDescription: " << lang->getDescription();
 
     Diluculum::LuaState* luaState=lang->getLuaState();
-    if (luaState){
-	cerr << "\n\nLUA GLOBALS:\n" ;
-	Diluculum::LuaValueMap::iterator it;
-	Diluculum::LuaValueMap glob =luaState->globals();
-	for(it = glob.begin(); it != glob.end(); it++)
-	{
-	  Diluculum::LuaValue first = it->first;
-	  Diluculum::LuaValue second = it->second;
-	  std::cerr << first.asString()<<": ";
-	  switch (second.type()) {
-	    case  LUA_TSTRING:	cerr << "string [ "<<second.asString()<<" ]";
-		    break;
-	    case  LUA_TNUMBER:	cerr << "number [ "<<second.asNumber()<<" ]";
-		    break;
-	    case  LUA_TBOOLEAN:	cerr << "boolean [ "<<second.asBoolean()<<" ]";
-		    break;
-	    default: cerr << second.typeName();
-	  }
-	  cerr << endl;
-	}
+    if (luaState) {
+        cerr << "\n\nLUA GLOBALS:\n" ;
+        Diluculum::LuaValueMap::iterator it;
+        Diluculum::LuaValueMap glob =luaState->globals();
+        for(it = glob.begin(); it != glob.end(); it++)
+        {
+            Diluculum::LuaValue first = it->first;
+            Diluculum::LuaValue second = it->second;
+            std::cerr << first.asString()<<": ";
+            switch (second.type()) {
+            case  LUA_TSTRING:
+                cerr << "string [ "<<second.asString()<<" ]";
+                break;
+            case  LUA_TNUMBER:
+                cerr << "number [ "<<second.asNumber()<<" ]";
+                break;
+            case  LUA_TBOOLEAN:
+                cerr << "boolean [ "<<second.asBoolean()<<" ]";
+                break;
+            default:
+                cerr << second.typeName();
+            }
+            cerr << endl;
+        }
 
     }
+    /*
     cerr << "\nREGEX:\n";
     highlight::RegexElement *re=NULL;
     for ( unsigned int i=0; i<lang->getRegexElements().size(); i++ )
     {
         re = lang->getRegexElements() [i];
-        cerr << "State "<<re->open<<":\t"<<re->rePattern->getPattern() <<"\n";
-    }
+        cerr << "State "<<re->open<<":\t"<<re->rex. <<"\n";
+    }*/
     cerr << "\nKEYWORDS:\n";
     highlight::KeywordMap::iterator it;
     highlight::KeywordMap keys=lang->getKeywords();
@@ -198,21 +198,11 @@ void HLCmdLineApp::printDebugInfo ( const highlight::SyntaxReader *lang,
     cerr <<"\n\n";
 }
 
-void HLCmdLineApp::printConfigInfo ( const string& configFile )
+void HLCmdLineApp::printConfigInfo ( )
 {
-    cout << "\nRoot paths (modify with --" OPT_DATADIR "):\n";
-    cout << "  Data directory:         "<<dataDir.getDir() <<"\n";
-    cout << "  Language definitions:   "<<dataDir.getLangPath ( "" ) <<"\n";
-    cout << "  Colour themes:          "<<dataDir.getThemePath ( "") <<"\n";
-
-    cout << "\nConfiguration paths:\n";
-    cout << "  Configuration files:    "<<dataDir.getConfDir ( true ) <<"\n";
-    cout << "  User configuration:     "<<configFile<<"\n";
-    if ( !dataDir.getAdditionalConfDir().empty() )
-    {
-        cout << "\nAdditional search paths:\n";
-        cout << "  Configuration files:    "<<dataDir.getAdditionalConfDir() <<"\n";
-    }
+    cout << "\nConfig file search directories:\n";
+    dataDir.printConfigPaths();
+    cout << "\nFiletype config file:\n"<<dataDir.getFiletypesConfPath ( "filetypes" ) <<"\n";
     cout << endl;
 #ifdef HL_DATA_DIR
     cout << "Compiler directive HL_DATA_DIR = " <<HL_DATA_DIR<< "\n";
@@ -220,47 +210,32 @@ void HLCmdLineApp::printConfigInfo ( const string& configFile )
 #ifdef HL_CONFIG_DIR
     cout << "Compiler directive HL_CONFIG_DIR = " <<HL_CONFIG_DIR<< "\n";
 #endif
-
     cout << endl;
 }
 
-/*
- * 
- * broken:
-string HLCmdLineApp::getFileSuffix ( const string &fileName )
-{
-    size_t ptPos=fileName.rfind ( "." );
-    size_t psPos = fileName.rfind ( Platform::pathSeparator );
-
-    if ( ptPos > psPos && ptPos != string::npos )
-        return fileName.substr ( ptPos+1, fileName.length() );
-    else
-        return "";
-}*/
-
 string HLCmdLineApp::getFileSuffix(const string& fileName)
 {
-  size_t ptPos=fileName.rfind(".");
-  size_t psPos = fileName.rfind ( Platform::pathSeparator );
-  return (ptPos == string::npos || (psPos!=string::npos && psPos>ptPos)) ? "" : fileName.substr(ptPos+1,
-                                        fileName.length());
+    size_t ptPos=fileName.rfind(".");
+    size_t psPos = fileName.rfind ( Platform::pathSeparator );
+    return (ptPos == string::npos || (psPos!=string::npos && psPos>ptPos)) ? "" : fileName.substr(ptPos+1,
+            fileName.length());
 }
 
 bool HLCmdLineApp::loadFileTypeConfig ( const string& name, StringMap* extMap, StringMap* shebangMap )
 {
     if ( !extMap || !shebangMap ) return false;
 
-    string confPath=dataDir.getConfDir() + name + ".conf";
-
+  //  string confPath=dataDir.getConfDir() + name + ".conf";
+    string confPath=dataDir.getFiletypesConfPath(name);
     try {
         Diluculum::LuaState ls;
         Diluculum::LuaValueList ret= ls.doFile (confPath);
 
         int idx=1;
         string langName;
-	Diluculum::LuaValue mapEntry;
+        Diluculum::LuaValue mapEntry;
         while ((mapEntry = ls["FileMapping"][idx].value()) !=Diluculum::Nil) {
-            langName = mapEntry["Lang"].asString(); 
+            langName = mapEntry["Lang"].asString();
             if (mapEntry["Extensions"] !=Diluculum::Nil) {
                 int extIdx=1;
                 while (mapEntry["Extensions"][extIdx] !=Diluculum::Nil) {
@@ -299,7 +274,7 @@ void HLCmdLineApp::printProgressBar ( int total, int count )
     int p=100*count / total;
     int numProgressItems=p/10;
     cout << "\r[";
-    for ( int i=0;i<10;i++ )
+    for ( int i=0; i<10; i++ )
     {
         cout << ( ( i<numProgressItems ) ?"#":" " );
     }
@@ -362,10 +337,12 @@ string HLCmdLineApp::analyzeFile ( const string& file )
         cin.rdbuf ( cin_bufcopy.rdbuf() );
     }
     StringMap::iterator it;
-    for ( it=scriptShebangs.begin(); it!=scriptShebangs.end();it++ )
+    boost::xpressive::sregex rex;
+    boost::xpressive::smatch what;
+    for ( it=scriptShebangs.begin(); it!=scriptShebangs.end(); it++ )
     {
-        pair<string, int> matched = Pattern::findNthMatch ( it->first, firstLine, 0 );
-        if ( matched.second >= 0 ) return it->second;
+        rex = boost::xpressive::sregex::compile( it->first );
+        if ( boost::xpressive::regex_search( firstLine, what, rex )  ) return it->second;
     }
     return "";
 }
@@ -377,14 +354,25 @@ string HLCmdLineApp::guessFileType ( const string& suffix, const string &inputFi
     string fileType = (extensions.count(lcSuffix)) ? extensions[lcSuffix] : lcSuffix ;
     if (!fileType.empty()) return fileType;
     return analyzeFile(inputFile);
-    
+
     /*if (suffix.empty()) return analyzeFile ( inputFile );
     string lcSuffix = StringTools::change_case ( suffix );
     return ( extensions.count ( lcSuffix ) ) ? extensions[lcSuffix] : lcSuffix ;*/
-   // if ( !fileType.empty() ) return fileType;
-   // return "";
+    // if ( !fileType.empty() ) return fileType;
+    // return "";
 }
 
+vector <string> HLCmdLineApp::collectPluginPaths(const vector<string>& plugins){
+  vector<string> absolutePaths;
+  for (unsigned int i=0; i<plugins.size(); i++) {
+    if (Platform::fileExists(plugins[i])){
+      absolutePaths.push_back(plugins[i]);
+    } else {
+	absolutePaths.push_back(dataDir.getPluginPath(plugins[i]+".lua"));
+    }
+  }
+  return absolutePaths;
+}
 
 int HLCmdLineApp::run ( const int argc, const char*argv[] )
 {
@@ -399,13 +387,7 @@ int HLCmdLineApp::run ( const int argc, const char*argv[] )
         return EXIT_SUCCESS;
     }
 
-    dataDir.setAdditionalConfDir ( options.getAdditionalConfDir() );
-
-    if ( ! dataDir.searchDataDir ( dataDirPath ) )
-    {
-        printBadInstallationInfo();
-        return EXIT_FAILURE;
-    }
+    dataDir.initSearchDirectories ( dataDirPath );
 
     if ( options.printHelp() )
     {
@@ -415,13 +397,17 @@ int HLCmdLineApp::run ( const int argc, const char*argv[] )
 
     if ( options.printConfigInfo() )
     {
-        printConfigInfo ( options.getConfigFilePath() );
+        printConfigInfo ( );
         return EXIT_SUCCESS;
     }
 
     if ( options.showThemes() )
     {
-        return printInstalledThemes() ?EXIT_SUCCESS:EXIT_FAILURE;
+        return printInstalledFiles(dataDir.getThemePath(), "*.theme", "themes", OPT_STYLE) ?EXIT_SUCCESS:EXIT_FAILURE;
+    }
+    if ( options.showPlugins() )
+    {
+        return printInstalledFiles(dataDir.getPluginPath(), "*.lua", "plug-ins", OPT_PLUGIN) ?EXIT_SUCCESS:EXIT_FAILURE;
     }
 
     //call before printInstalledLanguages!
@@ -429,7 +415,7 @@ int HLCmdLineApp::run ( const int argc, const char*argv[] )
 
     if ( options.showLangdefs() )
     {
-        return printInstalledLanguages() ?EXIT_SUCCESS:EXIT_FAILURE;
+        return printInstalledLanguages();
     }
 
     const  vector <string> inFileList=options.getInputFileNames();
@@ -463,6 +449,8 @@ int HLCmdLineApp::run ( const int argc, const char*argv[] )
         generator->setEOLDelimiter('\r');
 
     generator->setValidateInput ( options.validateInput() );
+    generator->setNumberWrappedLines ( options.numberWrappedLines() );
+
     generator->setStyleInputPath ( options.getStyleInFilename() );
     generator->setStyleOutputPath ( options.getStyleOutFilename() );
     generator->setIncludeStyle ( options.includeStyleDef() );
@@ -482,20 +470,20 @@ int HLCmdLineApp::run ( const int argc, const char*argv[] )
     generator->disableTrailingNL(options.disableTrailingNL());
     generator->setPluginReadFile(options.getPluginReadFilePath());
 
-    
+
     bool styleFileWanted = !options.fragmentOutput() || options.styleOutPathDefined();
 
-    const  vector <string> pluginFileList=options.getPluginPaths();
-    for (unsigned int i=0;i<pluginFileList.size();i++){
-    if ( !generator->initPluginScript(pluginFileList[i]) )
-    {
-        cerr << "highlight: "
-             << generator->getPluginScriptError()
-             << " in "
-             << pluginFileList[i]
-             <<"\n";
-        return EXIT_FAILURE;
-    }
+    const  vector <string> pluginFileList=collectPluginPaths( options.getPluginPaths());
+    for (unsigned int i=0; i<pluginFileList.size(); i++) {
+        if ( !generator->initPluginScript(pluginFileList[i]) )
+        {
+            cerr << "highlight: "
+                 << generator->getPluginScriptError()
+                 << " in "
+                 << pluginFileList[i]
+                 <<"\n";
+            return EXIT_FAILURE;
+        }
     }
 
     if ( !generator->initTheme ( themePath ) )
@@ -533,17 +521,6 @@ int HLCmdLineApp::run ( const int argc, const char*argv[] )
         return EXIT_FAILURE;
     }
 
-    if ( !options.getTagsFile().empty() )
-    {
-        if ( !generator->initTagInformation ( options.getTagsFile() ) )
-        {
-            cerr << "highlight: Could not load ctags file "
-                 << options.getTagsFile()
-                 << ".\n";
-            return EXIT_FAILURE;
-        }
-    }
-
     string outDirectory = options.getOutDirectory();
 #ifndef WIN32
     ifstream dirTest ( outDirectory.c_str() );
@@ -566,7 +543,7 @@ int HLCmdLineApp::run ( const int argc, const char*argv[] )
                  numBadOutput=0;
 
     vector<string> badFormattedFiles, badInputFiles, badOutputFiles;
-    set<string> usedFileNames;
+    std::set<string> usedFileNames;
     string inFileName, outFilePath;
     string suffix, lastSuffix;
 
@@ -581,6 +558,7 @@ int HLCmdLineApp::run ( const int argc, const char*argv[] )
         {
             suffix = guessFileType ( getFileSuffix ( inFileList[i] ), inFileList[i] );
         }
+        if ( suffix.empty()  && options.forceOutput()) suffix="txt"; //avoid segfault
         if ( suffix.empty() )
         {
             if ( !options.enableBatchMode() )
@@ -642,13 +620,13 @@ int HLCmdLineApp::run ( const int argc, const char*argv[] )
 
         if ( options.enableBatchMode() )
         {
-	    if (usedFileNames.count(inFileName)){
-	      string prefix=inFileList[i].substr (0, pos+1 );
-	      replace (prefix.begin(), prefix.end(), Platform::pathSeparator, '_');
-	      inFileName.insert(0, prefix);
-	    } else {
-	      usedFileNames.insert(inFileName);
-	    }
+            if (usedFileNames.count(inFileName)) {
+                string prefix=inFileList[i].substr (0, pos+1 );
+                replace (prefix.begin(), prefix.end(), Platform::pathSeparator, '_');
+                inFileName.insert(0, prefix);
+            } else {
+                usedFileNames.insert(inFileName);
+            }
             outFilePath = outDirectory;
             outFilePath += inFileName;
             outFilePath += options.getOutFileSuffix();
@@ -671,7 +649,7 @@ int HLCmdLineApp::run ( const int argc, const char*argv[] )
             if ( outFilePath.size() && outFilePath==options.getSingleInFilename() )
             {
                 cerr 	<< "highlight: Output path equals input path: \""
-                      << outFilePath << "\".\n";
+                        << outFilePath << "\".\n";
                 initError = true;
                 break;
             }
