@@ -34,6 +34,7 @@ along with Highlight.  If not, see <http://www.gnu.org/licenses/>.
 #include "showtextfile.h"
 #include "io_report.h"
 
+//#undef DATA_DIR
 
 MainWindow::MainWindow(QWidget *parent)
     : QMainWindow(parent), ui(new Ui::MainWindowClass), getDataFromCP(false)
@@ -78,6 +79,7 @@ MainWindow::MainWindow(QWidget *parent)
           constIterator != themes.constEnd(); ++constIterator) {
              ui->comboTheme->addItem(QString(*constIterator).section('.',0, 0));
     }
+    ui->comboTheme->setCurrentIndex(0);
 
     // load syntax mappings
    if (!loadFileTypeConfig(&extensions, &shebangs)){
@@ -99,7 +101,6 @@ MainWindow::MainWindow(QWidget *parent)
     QObject::connect(ui->cbHTMLEmbedStyle, SIGNAL(clicked()), this, SLOT(plausibility()));
     QObject::connect(ui->cbHTMLAnchors, SIGNAL(clicked()), this, SLOT(plausibility()));
     QObject::connect(ui->cbHTMLInlineCSS, SIGNAL(clicked()), this, SLOT(plausibility()));
-    QObject::connect(ui->cbHTMLCtags, SIGNAL(clicked()), this, SLOT(plausibility()));
     QObject::connect(ui->cbLATEXEmbedStyle, SIGNAL(clicked()), this, SLOT(plausibility()));
     QObject::connect(ui->cbTEXEmbedStyle, SIGNAL(clicked()), this, SLOT(plausibility()));
     QObject::connect(ui->cbSVGEmbedStyle, SIGNAL(clicked()), this, SLOT(plausibility()));
@@ -126,6 +127,7 @@ MainWindow::MainWindow(QWidget *parent)
 
     QObject::connect(ui->sbLineNoWidth, SIGNAL(valueChanged(int)), this, SLOT(updatePreview()));
     QObject::connect(ui->leFontSize, SIGNAL(textChanged(QString)), this, SLOT(updatePreview()));
+    QObject::connect(ui->cbOmitWrappedLineNumbers, SIGNAL(clicked()), this, SLOT(updatePreview()));
 
     setAcceptDrops(true);
 
@@ -140,24 +142,19 @@ MainWindow::~MainWindow()
 }
 
 void MainWindow::openFiles(){
-     QFileDialog dialog(this, tr("Select one or more files to open"),
-                         "",
-                         fileOpenFilter);
-     dialog.setFileMode(QFileDialog::ExistingFiles);
-     dialog.setViewMode(QFileDialog::Detail);
 
-     if (dialog.exec()) {
-            addInputFiles(dialog.selectedFiles(), ui->lvInputFiles);
-    }
+    QStringList files = QFileDialog::getOpenFileNames(
+                            this,
+                            tr("Select one or more files to open"),
+                            "",
+                            fileOpenFilter);
+
+     addInputFiles(files, ui->lvInputFiles);
 }
 
 void MainWindow::selectSingleFile(QLineEdit* edit, const QString& title, const QString& filter){
-     QFileDialog dialog(this, title, "", filter);
-     dialog.setFileMode(QFileDialog::ExistingFile);
-     dialog.setViewMode(QFileDialog::Detail);
-     if (dialog.exec()) {
-            edit->setText(dialog.selectedFiles().first());
-    }
+    QString fileName = QFileDialog::getOpenFileName(this, title, "", filter);
+    if (!fileName.isEmpty()) edit->setText(fileName);
 }
 
 void MainWindow::addInputFiles(const QStringList& list, QListWidget* listWidget, const QString& iconName, bool checkable ){
@@ -233,8 +230,7 @@ void MainWindow::on_pbOutputDest_clicked(){
                        ui->cbFragment->isChecked());
      settings.setValue(ui->cbHTMLAnchors->property(name).toString(),
                        ui->cbHTMLAnchors->isChecked());
-     settings.setValue(ui->cbHTMLCtags->property(name).toString(),
-                       ui->cbHTMLCtags->isChecked());
+
      settings.setValue(ui->cbHTMLEmbedStyle->property(name).toString(),
                        ui->cbHTMLEmbedStyle->isChecked());
      settings.setValue(ui->cbHTMLEnclosePreTags->property(name).toString(),
@@ -285,8 +281,6 @@ void MainWindow::on_pbOutputDest_clicked(){
      settings.setValue(ui->comboSelectSyntax->property(name).toString(),
                        ui->comboSelectSyntax->currentIndex());
 
-     settings.setValue(ui->leHTMLCtagsFile->property(name).toString(),
-                       ui->leHTMLCtagsFile->text());
      settings.setValue(ui->leHTMLStyleFile->property(name).toString(),
                        ui->leHTMLStyleFile->text());
      settings.setValue(ui->leHTMLStyleIncFile->property(name).toString(),
@@ -364,7 +358,6 @@ void MainWindow::on_pbOutputDest_clicked(){
      ui->cbEncoding->setChecked(settings.value(ui->cbEncoding->property(name).toString()).toBool());
      ui->cbFragment->setChecked(settings.value(ui->cbFragment->property(name).toString()).toBool());
      ui->cbHTMLAnchors->setChecked(settings.value(ui->cbHTMLAnchors->property(name).toString()).toBool());
-     ui->cbHTMLCtags->setChecked(settings.value(ui->cbHTMLCtags->property(name).toString()).toBool());
      ui->cbHTMLEmbedStyle->setChecked(settings.value(ui->cbHTMLEmbedStyle->property(name).toString()).toBool());
      ui->cbHTMLEnclosePreTags->setChecked(settings.value(ui->cbHTMLEnclosePreTags->property(name).toString()).toBool());
      ui->cbHTMLFileNameAnchor->setChecked(settings.value(ui->cbHTMLFileNameAnchor->property(name).toString()).toBool());
@@ -394,7 +387,6 @@ void MainWindow::on_pbOutputDest_clicked(){
      ui->comboTheme->setCurrentIndex(settings.value(ui->comboTheme->property(name).toString()).toInt());
      ui->comboSelectSyntax->setCurrentIndex(settings.value(ui->comboSelectSyntax->property(name).toString()).toInt());
 
-     ui->leHTMLCtagsFile->setText(settings.value(ui->leHTMLCtagsFile->property(name).toString()).toString());
      ui->leHTMLStyleFile->setText(settings.value(ui->leHTMLStyleFile->property(name).toString()).toString());
      ui->leHTMLStyleIncFile->setText(settings.value(ui->leHTMLStyleIncFile->property(name).toString()).toString());
      ui->leLATEXStyleFile->setText(settings.value(ui->leLATEXStyleFile->property(name).toString()).toString());
@@ -459,13 +451,14 @@ bool MainWindow::loadFileTypeConfig(StringMap* extMap, StringMap* shebangMap) {
     string firstLine;
     getline (inFile, firstLine);
     StringMap::iterator it;
-    /*for (it=shebangs.begin(); it!=shebangs.end();it++){
-       if (Pattern::matches(it->first, firstLine)) return it->second;
-    }*/
+
+    
+    boost::xpressive::sregex rex;
+    boost::xpressive::smatch what;
     for ( it=shebangs.begin(); it!=shebangs.end();it++ )
     {
-        pair<string, int> matched = Pattern::findNthMatch ( it->first, firstLine, 0 );
-        if ( matched.second >= 0 ) return it->second;
+        rex = boost::xpressive::sregex::compile( it->first );
+        if ( boost::xpressive::regex_search( firstLine, what, rex )  ) return it->second;
     }
     return "";
 }
@@ -475,12 +468,13 @@ string MainWindow::getFileType(const string& suffix, const string &inputFile)
     string lcSuffix = StringTools::change_case(suffix);
     string fileType = (extensions.count(lcSuffix)) ? extensions[lcSuffix] : lcSuffix ;
     if (!fileType.empty()) return fileType;
+
     return analyzeFile(inputFile);
 }
 
 string MainWindow::getFileSuffix(const string& fileName)
 {
-  unsigned int ptPos=fileName.rfind(".");
+  size_t ptPos=fileName.rfind(".");
   return (ptPos == string::npos) ? "" : fileName.substr(ptPos+1,
                                         fileName.length());
 }
@@ -507,12 +501,11 @@ void MainWindow::on_action_About_Highlight_triggered()
      QMessageBox::about( this, "About Highlight",
                          QString("Highlight is a code to formatted text converter.\n\n"
                          "Highlight GUI %1\n"
-                         "(C) 2002-2012 Andre Simon <andre.simon1 at gmx.de>\n\n"
+                         "(C) 2002-2013 Andre Simon <andre.simon1 at gmx.de>\n\n"
                          "Artistic Style Classes\n(C) 1998-2002 Tal Davidson\n"
                          "(C) 2006-2011 Jim Pattee <jimp03 at email.com>\n\n"
                          "Diluculum Lua wrapper\n"
-			 "(C) 2005-2010 by Leandro Motta Barros\n\n"
-                         "Regex library\n(C) 2003-2008 Jeffery Stuart <stuart at cs.unr.edu>\n\n"
+			 "(C) 2005-2013 by Leandro Motta Barros\n\n"
                          "Built with Qt version %2\n\n"
                          "Released under the terms of the GNU GPL license.\n\n"
                          "The highlight logo is based on the image \"Alcedo Atthis\" by Lukasz Lukasik.\n"
@@ -528,8 +521,9 @@ void MainWindow::on_action_About_Highlight_triggered()
      case 2: return highlight::LATEX;
      case 3: return highlight::TEX;
      case 4: return highlight::RTF;
-     case 5: return highlight::SVG;
-     case 6: return highlight::BBCODE;
+     case 5: return highlight::ODTFLAT;
+     case 6: return highlight::SVG;
+     case 7: return highlight::BBCODE;
     }
     return highlight::HTML;
 }
@@ -541,8 +535,9 @@ void MainWindow::on_action_About_Highlight_triggered()
     case 2:
     case 3: return ".tex";
     case 4: return ".rtf";
-    case 5: return ".svg";
-    case 6: return ".bbcode";
+    case 5: return ".fodt";
+    case 6: return ".svg";
+    case 7: return ".bbcode";
   }
   return ".html";
 }
@@ -591,6 +586,8 @@ void MainWindow::applyCtrlValues(highlight::CodeGenerator* generator, bool previ
           generator->setHTMLOrderedList(ui->cbHTMLOrderedList->isChecked());
           generator->setHTMLInlineCSS(ui->cbHTMLInlineCSS->isChecked() && ui->cbHTMLInlineCSS->isEnabled());
           generator->setHTMLEnclosePreTag(ui->cbHTMLEnclosePreTags->isChecked());
+        //  generator->setHTMLUseNonBreakingSpace(ui->cbHTMLNonBreakingSpace->isChecked());
+
           if (ui->leHTMLCssPrefix->text().size())
               generator->setHTMLClassName(ui->leHTMLCssPrefix->text().toStdString());
 
@@ -636,6 +633,7 @@ void MainWindow::applyCtrlValues(highlight::CodeGenerator* generator, bool previ
     }
     generator->setValidateInput(ui->cbValidateInput->isChecked());
     generator->setLineNumberWidth(ui->sbLineNoWidth->value());
+    generator->setNumberWrappedLines(!ui->cbOmitWrappedLineNumbers->isChecked());
 
     if (getOutputType()!=highlight::LATEX && getOutputType()!=highlight::TEX){
       string fntName=ui->comboFontName->currentText().toStdString();
@@ -667,14 +665,6 @@ void MainWindow::applyCtrlValues(highlight::CodeGenerator* generator, bool previ
        generator->initIndentationScheme(ui->comboReformat->currentText().toLower().toStdString());
 
     }
-
-   if (    ui->cbHTMLCtags->isChecked() && !ui->leHTMLCtagsFile->text().isEmpty()
-       && (outType==highlight::HTML || outType==highlight::XHTML)){
-       if (!generator->initTagInformation(ui->leHTMLCtagsFile->text().toStdString())){
-         QMessageBox::critical(this, tr("Tags file error"),
-                              tr("Could not read tags information in \"%1\"").arg(ui->leHTMLCtagsFile->text()));
-      }
-   }
 }
 
 highlight::WrapMode MainWindow::getWrappingStyle(){
@@ -766,6 +756,9 @@ void MainWindow::on_pbStartConversion_clicked(){
         } else  if (loadRes==highlight::LOAD_FAILED) {
            QMessageBox::warning(this, tr("Unknown syntax"), tr("Could not convert %1").arg(inFilePath));
            inputErrors.append(inFilePath);
+       } else  if (loadRes==highlight::LOAD_FAILED_LUA) {
+           QMessageBox::warning(this, tr("Lua error"), tr("Could not convert %1:\nLua Syntax error: %2").arg(inFilePath).arg(QString::fromStdString(generator->getSyntaxLuaError())) );
+           inputErrors.append(inFilePath);
        } else {
 
           if (ui->cbReformat->isChecked()&& !generator->formattingIsPossible()){
@@ -906,10 +899,10 @@ void MainWindow::highlight2Clipboard(bool getDataFromCP){
               highlight::OutputType outputType = getOutputType();
               if ( outputType==highlight::RTF){
                    QMimeData *mimeData = new QMimeData();
-#ifdef WIN32
-                  mimeData->setData("Rich Text Format", clipBoardData.toAscii());
+#ifdef Q_OS_WIN32
+                  mimeData->setData("Rich Text Format", clipBoardData.toLatin1());
 #else
-                  mimeData->setData("text/rtf", clipBoardData.toAscii());
+                  mimeData->setData("text/rtf", clipBoardData.toLatin1());
 #endif
                   clipboard->setMimeData(mimeData);
               } else {
@@ -940,8 +933,6 @@ void MainWindow::highlight2Clipboard(bool getDataFromCP){
      ui->leHTMLStyleIncFile->setEnabled(ui->cbHTMLEmbedStyle->isChecked() && !ui->cbHTMLInlineCSS->isChecked());
      ui->pbHTMLChooseStyleIncFile->setEnabled(ui->cbHTMLEmbedStyle->isChecked() &&!ui->cbHTMLInlineCSS->isChecked());
      ui->leHTMLCssPrefix->setEnabled(!ui->cbHTMLInlineCSS->isChecked());
-     ui->leHTMLCtagsFile->setEnabled(ui->cbHTMLCtags->isChecked());
-     ui->pbHTMLChooseTagsFile->setEnabled(ui->cbHTMLCtags->isChecked());
      ui->leLATEXStyleFile->setEnabled(!ui->cbLATEXEmbedStyle->isChecked());
      ui->leTEXStyleFile->setEnabled(!ui->cbTEXEmbedStyle->isChecked());
      ui->leSVGStyleFile->setEnabled(!ui->cbSVGEmbedStyle->isChecked());
@@ -970,7 +961,7 @@ void MainWindow::highlight2Clipboard(bool getDataFromCP){
     case 4:
          ui->stackedSpecificOptions->setCurrentIndex(3);
          break;
-    case 5:
+    case 6:
          ui->stackedSpecificOptions->setCurrentIndex(4);
          break;
     default:
@@ -1053,12 +1044,6 @@ void MainWindow::highlight2Clipboard(bool getDataFromCP){
  }
 
 
-
-void MainWindow::on_pbHTMLChooseTagsFile_clicked()
-{
-    selectSingleFile(ui->leHTMLCtagsFile, tr("Choose a ctags file"), "*");
-}
-
 void MainWindow::on_action_Manual_triggered()
 {
     ShowTextFile show;
@@ -1158,15 +1143,19 @@ void MainWindow::on_pbCopyToCP_clicked()
 
 void MainWindow::on_pbSelectPlugin_clicked()
 {
-    QFileDialog dialog(this, tr("Select one or more plug-ins"),
-                        "",
-                        "*.lua");
-    dialog.setFileMode(QFileDialog::ExistingFiles);
-    dialog.setViewMode(QFileDialog::Detail);
+#ifdef DATA_DIR
+    QString pluginsPath = QDir::toNativeSeparators(QString("%1/plugins").arg(DATA_DIR));
+#else
+     QString pluginsPath = QDir::toNativeSeparators(QString("%1/plugins").arg(QDir::currentPath()));
+#endif
 
-    if (dialog.exec()) {
-           addInputFiles(dialog.selectedFiles(), ui->lvPluginScripts, ":/plugin.png",  true);
-   }
+    QStringList files = QFileDialog::getOpenFileNames(
+                            this,
+                            tr("Select one or more plug-ins"),
+                            pluginsPath,
+                            "*.lua");
+
+     addInputFiles(files, ui->lvPluginScripts, ":/plugin.png",  true);
 }
 
 void MainWindow::on_pbClearSelPlugin_clicked()
@@ -1192,17 +1181,6 @@ void MainWindow::on_actionVisit_website_triggered()
     QDesktopServices::openUrl(QUrl("http://www.andre-simon.de/"));
 }
 
-void MainWindow::on_lvPluginScripts_itemClicked(QListWidgetItem* item)
-{
-    try {
-        Diluculum::LuaState ls;
-        ls.doFile (item->text().toStdString());
-        ui->lblPluginDescription->setText(QString::fromStdString(ls["Description"].value().asString()));
-    }
-    catch (Diluculum::LuaError err) {
-        QMessageBox::warning(this, "Plug-In error", QString::fromStdString( err.what()));
-    }
-}
 
 void MainWindow::on_actionDock_floating_panels_toggled(bool arg1)
 {
@@ -1213,3 +1191,15 @@ void MainWindow::on_pbPluginReadFilePath_clicked()
 {
        selectSingleFile(ui->lePluginReadFilePath, tr("Choose a plug-in input file"), "*");
 }
+
+void MainWindow::on_lvPluginScripts_currentRowChanged(int currentRow)
+{
+    try {
+        Diluculum::LuaState ls;
+        ls.doFile ( ui->lvPluginScripts->item(currentRow)->text().toStdString());
+        ui->lblPluginDescription->setText(QString::fromStdString(ls["Description"].value().asString()));
+    }
+    catch (Diluculum::LuaError err) {
+        QMessageBox::warning(this, "Plug-In error", QString::fromStdString( err.what()));
+    }
+}
