@@ -35,7 +35,6 @@ along with Highlight.  If not, see <http://www.gnu.org/licenses/>.
 
 #include "syntaxreader.h"
 #include "themereader.h"
-#include "ctagsreader.h"
 #include "astyle/astyle.h"
 #include "preformatter.h"
 #include "enums.h"
@@ -156,13 +155,6 @@ namespace highlight
 			 */
 			bool initIndentationScheme ( const string&indentScheme );
 
-			/**
-			 Load ctags meta information; needs to be called before using a generate* method
-			 \param ctagsPath Path of tags file
-			 \return true if successfull
-			*/
-			bool initTagInformation ( const string& ctagsPath );
-
 			/** \param langDefPath Absolute path to language definition, may be used multiple times for a generator instance
 			    \return   LOAD_OK,
 				      LOAD_FAILED,
@@ -266,6 +258,13 @@ namespace highlight
 			/** \return input validation flag */
 			bool getValidateInput();
 
+			/** if true, wrapped lines receive unique line numbers.
+			 *  else, wrapped lines don't have line numbers at all. */
+			void setNumberWrappedLines ( bool flag );
+
+			/** return number wrapped lines flag */
+			bool getNumberWrappedLines ();
+
 			/** \return style path */
 			const string& getStyleName();
 
@@ -337,14 +336,14 @@ namespace highlight
 				\param langName name of nested language
 			*/
 			void setStartingNestedLang(const string &langName);
-			
+
 			/** \param path path of plugin input file
 			*/
 			void setPluginReadFile ( const string& path );
 
 			/** Load the Lua functions og the plug-in script
 				\param script path of the plug-in script
-				\param scriptInputFile path of the optional file to be read by the plugin 
+				\param scriptInputFile path of the optional file to be read by the plugin
 			*/
 			bool initPluginScript(const string& script);
 
@@ -376,6 +375,10 @@ namespace highlight
 			 */
 			virtual void setHTMLEnclosePreTag ( bool )  {};
 
+			/** set HTML output replace space by &nbsp; flag
+			 */
+			virtual void setHTMLUseNonBreakingSpace ( bool )  {};
+
 			/** set HTML output anchor prefix
 			 */
 			virtual void setHTMLAnchorPrefix ( const string& )  {};
@@ -422,6 +425,7 @@ namespace highlight
 			static const string STY_NAME_DST;
 			static const string STY_NAME_LIN;
 			static const string STY_NAME_SYM;
+			static const string STY_NAME_IPL;
 
 			/** \param type Output type */
 			CodeGenerator ( highlight::OutputType type );
@@ -446,18 +450,16 @@ namespace highlight
 			ThemeReader docStyle;
 
 			/** Language definition*/
-			//SyntaxReader langInfo;
 			SyntaxReader* currentSyntax;
 
-			/** CTags meta information */
-			CTagsReader metaInfo;
-
 			/** Tag for inserting line feeds*/
 			string newLineTag;
 
 			/** String that represents a white space in output */
 			string spacer;
 
+			//char inputBuffer [1024*1024];
+
 			/** file input*/
 			istream *in;
 
@@ -558,6 +560,10 @@ namespace highlight
 			/** Class for line wrapping and tab replacement*/
 			PreFormatter preFormatter;
 
+			/** Stores if the current line should receive a line number.
+			 *  If the line is just the continuation of a wrapped line,
+			 *  and numberWrappedLines is false, this is set true. */
+			bool numberCurrentLine;
 		private:
 
 			CodeGenerator ( const CodeGenerator& ) {}
@@ -594,12 +600,12 @@ namespace highlight
 			   \param info tag information of current token
 			   \return opening tag
 			 */
-			virtual string getMetaInfoOpenTag ( const TagInfo& info ) {return "";}
+			//virtual string getMetaInfoOpenTag ( const TagInfo& info ) {return "";}
 
 			/** return close tag of meta information
 			   \return closing tag
 			 */
-			virtual string getMetaInfoCloseTag() {return "";}
+			//virtual string getMetaInfoCloseTag() {return "";}
 
 			/** open a new tag, set current state to s*/
 			void openTag ( State s );
@@ -621,7 +627,7 @@ namespace highlight
 
 			/// path to embedded language definition
 			string embedLangDefPath;
-			
+
 			/// path to plugin input file
 			string pluginReadFile;
 
@@ -652,8 +658,11 @@ namespace highlight
 			/** Flag to test if input should be validated (binary or text) */
 			bool validateInput;
 
+			/** Flag if wrapped lines should receive unique line numbers as well */
+			bool numberWrappedLines;
+
 			/** Flag to test if ctags information is available */
-			bool tagsEnabled;
+			//bool tagsEnabled;
 
 			/** Flag to test if trailing newline should be printed */
 			bool noTrailingNewLine;
@@ -694,6 +703,7 @@ namespace highlight
 			bool processSingleLineCommentState();     ///< process single line comments
 			bool processStringState ( State oldState );  ///< process strings
 			bool processEscapeCharState();            ///< process escape characters
+			bool processInterpolationState();         ///< process string interpolation sequences
 			bool processDirectiveState();             ///< process directives
 			bool processTagState();                   ///< process tags
 			bool processSymbolState();                ///< process symbols
@@ -701,11 +711,11 @@ namespace highlight
 			bool processSyntaxChangeState(State myState ); ///< process syntax change of embedded languages
 
 			/** print escaped token and clears it
-			   \param addMetaInfo set true if token may have meta information
+
 			   \param flushWhiteSpace set true if white space should be flushed
 			   \param tcase keyword case
 			*/
-			void printMaskedToken ( bool addMetaInfo = false, bool flushWhiteSpace = true,
+			void printMaskedToken ( /*bool addMetaInfo = false,*/ bool flushWhiteSpace = true,
 			                        StringTools::KeywordCase tcase = StringTools::CASE_UNCHANGED );
 
 			/** association of matched regexes and the corresponding keyword class ids*/
@@ -722,7 +732,7 @@ namespace highlight
 			bool validateInputStream();
 
 			/** load syntax description of embedded snippet's language
-			 \param embedLangDefPath path to language definition 
+			 \param embedLangDefPath path to language definition
 			  \return true if successfull */
 			bool loadEmbeddedLang(const string&embedLangDefPath);
 
@@ -732,10 +742,9 @@ namespace highlight
 			 \param kwClass keyword class ID if newState is KEYWORD
 			 */
 			State validateState(State newState, State oldState, unsigned int kwClass);
-			
+
 			/** \deprecated replace by Lua functionality */
 			bool checkSpecialCmd();
-
 	};
 
 }
